@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -22,11 +22,11 @@ void ProgressStatusBarWidgetTest::shouldHaveDefaultValue()
     KPIM::ProgressStatusBarWidget w(widget, widget);
     widget->show();
 
-    auto *progressDialog = widget->findChild<KPIM::ProgressDialog *>(QStringLiteral("progressDialog"));
+    auto progressDialog = widget->findChild<KPIM::ProgressDialog *>(QStringLiteral("progressDialog"));
     QVERIFY(progressDialog);
     QVERIFY(progressDialog->isHidden());
 
-    auto *mLittleProgress = widget->findChild<KPIM::StatusbarProgressWidget *>(QStringLiteral("littleprogress"));
+    auto mLittleProgress = widget->findChild<KPIM::StatusbarProgressWidget *>(QStringLiteral("littleprogress"));
     QVERIFY(mLittleProgress);
     QVERIFY(mLittleProgress->isVisible());
 
