@@ -1,31 +1,14 @@
 /*
   This file is part of libkdepim.
 
-  Copyright (c) 2008 Thomas Thrainer <tom_t@gmx.at>
-  Copyright (c) 2010 Bertjan Broeksema <broeksema@kde.org>
+  SPDX-FileCopyrightText: 2008 Thomas Thrainer <tom_t@gmx.at>
+  SPDX-FileCopyrightText: 2010 Bertjan Broeksema <broeksema@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #include "kcheckcombobox.h"
 
-#include <KLineEdit>
 #include "libkdepim_debug.h"
 
 #include <QAbstractItemView>
@@ -35,41 +18,40 @@
 
 using namespace KPIM;
 
-/// Class KCheckComboBox::Private
+/// Class KCheckComboBox::KCheckComboBoxPrivate
 
-namespace KPIM {
-class Q_DECL_HIDDEN KCheckComboBox::Private
+namespace KPIM
+{
+class Q_DECL_HIDDEN KCheckComboBox::KCheckComboBoxPrivate
 {
-    KCheckComboBox *q = nullptr;
-
 public:
-    Private(KCheckComboBox *qq)
-        : q(qq)
-        , mSeparator(QLatin1Char(','))
-        , mSqueezeText(false)
-        , mIgnoreHide(false)
-        , mAlwaysShowDefaultText(false)
+    KCheckComboBoxPrivate(KCheckComboBox *qq)
+        : mSeparator(QLatin1Char(','))
+        , q(qq)
     {
     }
 
     void makeInsertedItemsCheckable(const QModelIndex &, int start, int end);
-    QString squeeze(const QString &text);
+    Q_REQUIRED_RESULT QString squeeze(const QString &text);
     void updateCheckedItems(const QModelIndex &topLeft = QModelIndex(), const QModelIndex &bottomRight = QModelIndex(), int role = Qt::DisplayRole);
     void toggleCheckState();
 
 public:
     QString mSeparator;
     QString mDefaultText;
-    bool mSqueezeText;
-    bool mIgnoreHide;
-    bool mAlwaysShowDefaultText;
+    bool mSqueezeText = false;
+    bool mIgnoreHide = false;
+    bool mAlwaysShowDefaultText = false;
+
+private:
+    KCheckComboBox *const q;
 };
 }
 
-void KCheckComboBox::Private::makeInsertedItemsCheckable(const QModelIndex &parent, int start, int end)
+void KCheckComboBox::KCheckComboBoxPrivate::makeInsertedItemsCheckable(const QModelIndex &parent, int start, int end)
 {
-    Q_UNUSED(parent);
-    QStandardItemModel *model = qobject_cast<QStandardItemModel *>(q->model());
+    Q_UNUSED(parent)
+    auto model = qobject_cast<QStandardItemModel *>(q->model());
     if (model) {
         for (int r = start; r <= end; ++r) {
             QStandardItem *item = model->item(r, 0);
@@ -80,7 +62,7 @@ void KCheckComboBox::Private::makeInsertedItemsCheckable(const QModelIndex &pare
     }
 }
 
-QString KCheckComboBox::Private::squeeze(const QString &text)
+QString KCheckComboBox::KCheckComboBoxPrivate::squeeze(const QString &text)
 {
     QFontMetrics fm(q->fontMetrics());
     // The 4 pixels is 2 * horizontalMargin from QLineEdit.
@@ -97,10 +79,10 @@ QString KCheckComboBox::Private::squeeze(const QString &text)
     return text;
 }
 
-void KCheckComboBox::Private::updateCheckedItems(const QModelIndex &topLeft, const QModelIndex &bottomRight, int role)
+void KCheckComboBox::KCheckComboBoxPrivate::updateCheckedItems(const QModelIndex &topLeft, const QModelIndex &bottomRight, int role)
 {
-    Q_UNUSED(topLeft);
-    Q_UNUSED(bottomRight);
+    Q_UNUSED(topLeft)
+    Q_UNUSED(bottomRight)
 
     const QStringList items = q->checkedItems(role);
     QString text;
@@ -119,15 +101,14 @@ void KCheckComboBox::Private::updateCheckedItems(const QModelIndex &topLeft, con
     Q_EMIT q->checkedItemsChanged(items);
 }
 
-void KCheckComboBox::Private::toggleCheckState()
+void KCheckComboBox::KCheckComboBoxPrivate::toggleCheckState()
 {
     if (q->view()->isVisible()) {
         const QModelIndex index = q->view()->currentIndex();
-        QVariant value = index.data(Qt::CheckStateRole);
+        const QVariant value = index.data(Qt::CheckStateRole);
         if (value.isValid()) {
-            Qt::CheckState state = static_cast<Qt::CheckState>(value.toInt());
-            q->model()->setData(index, state == Qt::Unchecked ? Qt::Checked : Qt::Unchecked,
-                                Qt::CheckStateRole);
+            const auto state = static_cast<Qt::CheckState>(value.toInt());
+            q->model()->setData(index, state == Qt::Unchecked ? Qt::Checked : Qt::Unchecked, Qt::CheckStateRole);
         }
     }
 }
@@ -135,32 +116,29 @@ void KCheckComboBox::Private::toggleCheckState()
 /// Class KCheckComboBox
 
 KCheckComboBox::KCheckComboBox(QWidget *parent)
-    : KComboBox(parent)
-    , d(new KCheckComboBox::Private(this))
+    : QComboBox(parent)
+    , d(new KCheckComboBox::KCheckComboBoxPrivate(this))
 {
-    connect(this, qOverload<int>(&KComboBox::activated), this, [this]() {
+    connect(this, &QComboBox::activated, this, [this]() {
         d->toggleCheckState();
     });
-    connect(model(), &QAbstractItemModel::rowsInserted, this,
-            [this](const QModelIndex &index, int start, int end) {
+    connect(model(), &QAbstractItemModel::rowsInserted, this, [this](const QModelIndex &index, int start, int end) {
         d->makeInsertedItemsCheckable(index, start, end);
     });
     connect(model(), &QAbstractItemModel::dataChanged, this, [this](const QModelIndex &topLeft, const QModelIndex &bottomRight) {
         d->updateCheckedItems(topLeft, bottomRight);
     });
 
-
     // read-only contents
     setEditable(true);
 
     lineEdit()->setAlignment(Qt::AlignLeft);
     connect(lineEdit(), &QLineEdit::textChanged, this, [this](const QString &text) {
         if (text.isEmpty()) {
-            //Clear checked items
+            // Clear checked items
             setCheckedItems(QStringList());
         }
     });
-    setInsertPolicy(KComboBox::NoInsert);
 
     view()->installEventFilter(this);
     view()->viewport()->installEventFilter(this);
@@ -170,15 +148,12 @@ KCheckComboBox::KCheckComboBox(QWidget *parent)
     d->updateCheckedItems();
 }
 
-KCheckComboBox::~KCheckComboBox()
-{
-    delete d;
-}
+KCheckComboBox::~KCheckComboBox() = default;
 
 void KCheckComboBox::hidePopup()
 {
     if (!d->mIgnoreHide) {
-        KComboBox::hidePopup();
+        QComboBox::hidePopup();
     }
     d->mIgnoreHide = false;
 }
@@ -198,8 +173,8 @@ QStringList KCheckComboBox::checkedItems(int role) const
     QStringList items;
     if (model()) {
         const QModelIndex index = model()->index(0, modelColumn(), rootModelIndex());
-        const QModelIndexList indexes = model()->match(index, Qt::CheckStateRole,
-                                                       Qt::Checked, -1, Qt::MatchExactly);
+        const QModelIndexList indexes = model()->match(index, Qt::CheckStateRole, Qt::Checked, -1, Qt::MatchExactly);
+        items.reserve(indexes.count());
         for (const QModelIndex &index : indexes) {
             items += index.data(role).toString();
         }
@@ -249,7 +224,7 @@ bool KCheckComboBox::itemEnabled(int index)
 {
     Q_ASSERT(index >= 0 && index <= count());
 
-    QStandardItemModel *itemModel = qobject_cast<QStandardItemModel *>(model());
+    auto itemModel = qobject_cast<QStandardItemModel *>(model());
     Q_ASSERT(itemModel);
 
     QStandardItem *item = itemModel->item(index, 0);
@@ -260,7 +235,7 @@ void KCheckComboBox::setItemEnabled(int index, bool enabled)
 {
     Q_ASSERT(index >= 0 && index <= count());
 
-    QStandardItemModel *itemModel = qobject_cast<QStandardItemModel *>(model());
+    auto itemModel = qobject_cast<QStandardItemModel *>(model());
     Q_ASSERT(itemModel);
 
     QStandardItem *item = itemModel->item(index, 0);
@@ -311,7 +286,7 @@ void KCheckComboBox::wheelEvent(QWheelEvent *event)
 
 void KCheckComboBox::resizeEvent(QResizeEvent *event)
 {
-    KComboBox::resizeEvent(event);
+    QComboBox::resizeEvent(event);
     if (d->mSqueezeText) {
         d->updateCheckedItems();
     }
@@ -352,7 +327,7 @@ bool KCheckComboBox::eventFilter(QObject *receiver, QEvent *event)
     default:
         break;
     }
-    return KComboBox::eventFilter(receiver, event);
+    return QComboBox::eventFilter(receiver, event);
 }
 
 bool KCheckComboBox::alwaysShowDefaultText() const
